@@ -7,14 +7,7 @@ use Test::Darcs;
 use Shell::Command;
 use strict;
 
-cleanup 'temp1';
-mkpath 'temp1';
-chdir 'temp1';
-darcs 'init';
-open (DEF, ">_darcs/prefs/defaults") || die "Couldn't write to defaults.";
-print DEF "ALL --author tester";
-print DEF "ALL --ignore-times";
-close(DEF);
+init_tmp_repo();
 
 {
   my $testname = "RT#544 using context created with 8-bit chars";
@@ -28,13 +21,5 @@ close(DEF);
   system 'date > foo';
   like ( darcs("record -a -m 'date foo'"), qr/Finished record/,
          'recorded patch modifying foo');
-  like ( darcs('send -a -o patch --context context .'), qr/^$/, $testname );
+  like ( darcs('send -a -o patch --context context .'), qr/Wrote patch to/, $testname );
 }
-
-chdir '../';
-cleanup('temp1');
-ok((!-d 'temp1'), 'temp1 directory was deleted');
-
-
-
-
