@@ -2,29 +2,24 @@
 
 # Some tests for launching external commands
 
-use lib qw(lib/perl);
-
-use Test::More qw/no_plan/;
-
+use lib 'lib/perl';
+use Test::More 'no_plan';
 use Test::Darcs;
 use Shell::Command;
-
+use File::Slurp;
 use strict;
 
-cleanup  'temp1';
-mkpath 'temp1';
-chdir  'temp1';
-darcs 'init';
+init_tmp_repo();
 
 my $touch_fakessh='touch-fakessh';
-$touch_fakessh.='.bat' if ($^O =~ /msys/i);
+$touch_fakessh.='.bat' if ($^O =~ /(msys|win32)/i);
 
 cleanup  'fakessh';
 cleanup  'touch-fakessh';
 ###
 
 # make our ssh command one word only
-`echo 'echo hello > fakessh' > $touch_fakessh`;
+write_file($touch_fakessh,'echo hello > fakessh');
 `chmod u+x $touch_fakessh`;
 # add our fake ssh command to the environment
 $ENV{DARCS_SSH}="./$touch_fakessh";
@@ -40,6 +35,3 @@ darcs(qw(get temp2));
 ok(! -e 'fakessh');
 darcs(qw(get http://foo.bar:baz));
 ok(! -e 'fakessh');
-
-chdir '..';
-cleanup 'temp1';
