@@ -1,51 +1,48 @@
-#!/bin/sh
-
+#!/usr/bin/env bash
 
 set -ev
 
-test $DARCS || DARCS=$PWD/../darcs
-
 rm -rf temp1
 mkdir temp1
 cd temp1
-$DARCS init
+darcs init
 touch foo
-$DARCS add foo
+darcs add foo
 
 # Check that prompting works as expected when answering yes...
-echo yes | $DARCS whatsnew -s --posthook 'touch posthook-ran'
+echo yes | darcs whatsnew -s --posthook 'touch posthook-ran'
 test -f posthook-ran
 rm posthook-ran
 
 # Check that prompting works as expected when answering no...
-echo no | $DARCS whatsnew -s --posthook 'touch posthook-ran'
-test ! -e posthook-ran
+echo no | darcs whatsnew -s --posthook 'touch posthook-ran'
+test ! -f posthook-ran
 
 # Check that prompting works as expected with defaults (yes)...
 echo ALL --posthook touch posthook-ran > _darcs/prefs/defaults
-echo yes | $DARCS whatsnew -s
+echo yes | darcs whatsnew -s
 test -f posthook-ran
 rm posthook-ran
 
 # Check that prompting works as expected with defaults (no)...
-echo no | $DARCS whatsnew -s
-test ! -e posthook-ran
+echo no | darcs whatsnew -s
+test ! -f posthook-ran
 
 # Check that --run-posthook works in defaults
 echo ALL --run-posthook >> _darcs/prefs/defaults
-$DARCS whatsnew -s
+darcs whatsnew -s
 test -f posthook-ran
 rm posthook-ran
 
 # Check that --run-posthook works when specified both in defaults and on
 # command line
-$DARCS whatsnew --run-posthook -s
+darcs whatsnew --run-posthook -s
 test -f posthook-ran
 rm posthook-ran
 
 # Check that --posthook works when --run-posthook is in defaults
 echo ALL --run-posthook > _darcs/prefs/defaults
-$DARCS whatsnew --posthook 'touch posthook-ran' -s
+darcs whatsnew --posthook 'touch posthook-ran' -s
 test -f posthook-ran
 rm posthook-ran
 
