@@ -2,9 +2,8 @@
 
 # Some tests for 'darcs printer (the output formating)'
 
-use lib qw(lib/perl);
-
 BEGIN {
+    use lib 'lib/perl';
     use Test::More;
     if ($] < 5.008) {
         plan( skip_all => "sufficient UTF support may not be present under this Perl version ($])");
@@ -14,20 +13,15 @@ BEGIN {
     }
 }
 
-
 use Test::Darcs;
 use Shell::Command;
-
 use strict;
 
-rm_rf  'temp1';
-mkpath 'temp1';
-chdir  'temp1';
-darcs 'init';
+init_tmp_repo();
 
 touch 'a';
 darcs 'add a';
-darcs 'rec -a -A a -m add';
+darcs 'rec -a -m add';
 
 
 # clear all output formating environment variables
@@ -137,8 +131,3 @@ test_line('other chars are escaped with \xXX (8/8)',
           "\xF0\xF1\xF2\xF3\xF4\xF5\xF6\xF7\xF8\xF9\xFA\xFB\xFC\xFD\xFE\xFF",
           qr/\[_\\f0_\]\[_\\f1_\]\[_\\f2_\]\[_\\f3_\]\[_\\f4_\]\[_\\f5_\]\[_\\f6_\]\[_\\f7_\]\[_\\f8_\]\[_\\f9_\]\[_\\fa_\]\[_\\fb_\]\[_\\fc_\]\[_\\fd_\]\[_\\fe_\]\[_\\ff_\]/
          );
-
-
-chdir '../';
-rm_rf 'temp1';
-ok((!-d 'temp1'), 'temp1 directory was deleted');
