@@ -2,14 +2,14 @@
 
 # Some tests for 'darcs push' 
 
-use lib qw(lib/perl);
-use Test::More tests => 10;
+use lib 'lib/perl';
+use Test::More tests => 7;
 use Test::Darcs;
 use Shell::Command;
 use strict;
+use File::Temp 'tempdir';
+chdir tempdir( CLEANUP => 1 );
 
-cleanup  'temp1';
-cleanup  'temp2';
 mkpath 'temp1';
 mkpath 'temp2/one/two';
 chdir 'temp1';
@@ -37,16 +37,14 @@ chdir '../';
 {
     my $test_name = 'darcs push should push into repo specified with --repo';
     chdir './temp2';  
-    darcs  qw/add one/;
-    darcs qw!record --patch-name 'uno' --all --author foo\@bar!;
+    darcs 'add one';
+    darcs "record --patch-name 'uno' --all";
     chdir '../';     # now outside of any repo
 
-    like(darcs(qw!push --repodir temp2 --all ../temp1!), # temp2 is relative to temp1
+    like(darcs(qw!push --repodir temp2 --all "../temp1"!), # temp2 is relative to temp1
             qr/Finished apply./i, $test_name);
 }
 
-
-
 SELF_PUSH: {
     chdir './temp1'; 
 
@@ -56,21 +54,10 @@ SELF_PUSH: {
     my $test_name = 'return special message when you try to push to yourself';
     use Cwd;
     like( darcs(qw/push -a/,getcwd()), qr/Can't push to current repository!/i, $test_name);
+    like( darcs(qw/push -a ./), qr/Can't push to current repository!/i, $test_name);
 
     my $set_default_repo_test = "and don't update the default repo to be the current dir";
     ok( (! -r './_darcs/prefs/defaultrepo'),$set_default_repo_test);
 
     chdir '../';     # now outside of any repo
 }
-
-ok(-d 'temp1', "temp1 exists here");
-cleanup 'temp1';
-ok((!-d 'temp1'), 'temp1 directory was deleted');
-
-ok(-d 'temp2', "temp2 exists here");
-cleanup 'temp2';
-ok((!-d 'temp2'), 'temp2 directory was deleted');
-
-
-
-
