@@ -2,12 +2,14 @@
 
 # Some tests for 'darcs put' 
 
-use lib ('lib/perl');
-use Test::More qw/no_plan/;
+use lib 'lib/perl';
+use Test::More 'no_plan';
 use Test::Darcs;
 use Shell::Command;
 use Cwd;
 use strict;
+use File::Temp 'tempdir';
+chdir tempdir( CLEANUP => 1 );
 
 cleanup  qw/temp1 temp2/;
 mkpath 'temp1';
@@ -20,7 +22,7 @@ chdir '../';
   chdir './temp1';
   touch '1.txt';
   darcs qw/add 1.txt/;
-  darcs (qw/record -A x -a -m foo 1.txt/);
+  darcs (qw/record -a -m foo 1.txt/);
   darcs (qw% put ../temp2 %);
   
   my $default_repo;
@@ -62,16 +64,3 @@ SELF_PUT: {
 
     chdir '../';     # now outside of any repo
 }
-
-
-ok(-d 'temp1', "temp1 exists here");
-cleanup 'temp1';
-ok((!-d 'temp1'), 'temp1 directory was deleted');
-
-ok(-d 'temp2', "temp2 exists here");
-cleanup 'temp2';
-ok((!-d 'temp2'), 'temp2 directory was deleted');
-
-
-
-
