@@ -2,35 +2,37 @@
 
 # Some tests for the --set-scripts-executable option.
 
-use lib qw(lib/perl);
-use Test::More qw/no_plan/;
+use lib 'lib/perl';
+use Test::More 'no_plan';
 use Test::Darcs;
 use Shell::Command;
 use strict;
+use Cwd 'abs_path';
 
-if ($^O =~ /msys/i) {
+my $test_dir = abs_path();
+
+if ($^O =~ /win/i) {
     pass 'test does not work on windows';
 } else {
     my $test_name = 'darcs pull --set-scripts-executable works';
 
-    cleanup  'temp1';
-    cleanup  'temp2';
+    use File::Temp 'tempdir';
+    chdir tempdir( CLEANUP => 1 );
+
     mkpath 'temp1';
     chdir 'temp1';
     darcs 'init';
-    chdir '..';
 
-    cp __FILE__, 'temp1/script.pl' || die $!;
-    chmod 0644, 'temp1/script.pl' || die $!;
-    system 'date > temp1/nonscript';
-    ok( (-r 'temp1/script.pl'), 'pre test: script exists and is readable' );
-    ok( ! (-x 'temp1/script.pl'), 'pre test: script is not executable' );
-    ok( (-r 'temp1/nonscript'), 'pre test: nonscript exists and is readable' );
-    ok( ! (-x 'temp1/nonscript'), 'pre test: nonscript is not executable' );
+    cp "$test_dir/".__FILE__, 'script.pl' || die $!;
+    chmod 0644, 'script.pl' || die $!;
+    system 'date > nonscript';
+    ok( (-r 'script.pl'), 'pre test: script exists and is readable' );
+    ok( ! (-x 'script.pl'), 'pre test: script is not executable' );
+    ok( (-r 'nonscript'), 'pre test: nonscript exists and is readable' );
+    ok( ! (-x 'nonscript'), 'pre test: nonscript is not executable' );
 
-    chdir './temp1';  
-    darcs  qw/add script.pl nonscript/;
-    like( ( darcs qw!record --patch-name 'uno' --all --author foo\@bar! ), qr/finished recording/i );
+    darcs  'add script.pl nonscript';
+    like( ( darcs qw!record --patch-name 'uno' --all ! ), qr/finished recording/i );
     ok( chdir '..');
     # sans --set-scripts-executable (should not be executable)
     mkpath 'temp2';
@@ -45,7 +47,7 @@ if ($^O =~ /msys/i) {
     chdir '..';
 
     # darcs pull --set-scripts-executable
-    `rm -rf temp2`;
+    cleanup 'temp2';
     mkpath 'temp2';
     chdir 'temp2';
     darcs 'init';
@@ -68,18 +70,4 @@ if ($^O =~ /msys/i) {
 
     ok( (-x 'script.pl'), $test_name );
     ok(! (-x 'nonscript'), "innocent bystanders aren't set to be executable" );
-    chdir '../';     # now outside of any repo
-
-    ok(-d 'temp1', "temp1 exists here");
-    cleanup 'temp1';
-    ok((!-d 'temp1'), 'temp1 directory was deleted');
-
-    ok(-d 'temp2', "temp2 exists here");
-    cleanup 'temp2';
-    ok((!-d 'temp2'), 'temp2 directory was deleted');
-
 }
-
-
-
-
