@@ -3,26 +3,19 @@
 # Some tests for 'darcs whatsnew '
 
 use lib 'lib/perl';
-use Test::More qw/no_plan/;
+use Test::More 'no_plan';
 use Shell::Command;
 use Test::Darcs;
 use Shell::Command;
+use File::Slurp;
 use strict;
+use Cwd 'abs_path';
 
-cleanup 'temp1';
-mkpath 'temp1';
-chdir 'temp1';
-darcs 'init';
-open (DEF, ">_darcs/prefs/defaults") || die "Couldn't write to defaults.";
-print DEF "ALL --author tester";
-print DEF "ALL --ignore-times";
-close(DEF);
+init_tmp_repo();
 
 {
   my $testname = "RT#505 whatsnew -s after removal of file without a newline";
-  open(FOO,'>foo');
-  print FOO "foobar";
-  close(FOO);
+  write_file('foo',"foobar");
   like ( darcs('record -la -m "add foo"'), qr/Finished record/,
          'recorded patch adding foo');
   rm_rf 'foo';
@@ -39,31 +32,21 @@ close(DEF);
 
 my $test_name = 'whatsnew works with uncommon file names';
 
-if ($^O =~ /msys/i) {
+if ($^O =~ /(msys|win32)/i) {
     pass 'test does not work on windows';
 } else {
     touch(qw/\\/);
 
     my $before  = darcs(qw/add \\\\/);
-    my $what = darcs('whatsnew');
+    my $what = darcs 'whatsnew';
     unlike($what, qr/no changes/i, $test_name);
 }
 
 {
     my $test_name = 'whatsnew works with absolute paths';
-    my $abs_repo_path = `pwd`;
-    open(FOO,'>date.t');
-    print FOO "date.t";
-    close(FOO);
-    touch('date.t');
-    darcs(qw/add date.t/);
-    like( darcs('whatsnew', $abs_repo_path."/date.t"), qr/hunk/i, $test_name);
+    my $abs_repo_path = abs_path();
+    write_file('date.t','date.t');
+    touch 'date.t';
+    darcs 'add date.t';
+    like( darcs(qq{whatsnew  "$abs_repo_path/date.t"}), qr/hunk/i, $test_name);
 }
-
-chdir '../';
-cleanup('temp1');
-ok((!-d 'temp1'), 'temp1 directory was deleted');
-
-
-
-
